from rrutil import *

send_gdb('c')
expect_rr('Hi')

ok()
